y# Sammen

Together (Dansk: sammen) - watch multiple artifacts to ensure special events come together or go away.

[License: MIT](https://git.sr.ht/~sthagen/sammen/tree/default/item/LICENSE) | 
[Country of origin: Switzerland](https://git.sr.ht/~sthagen/sammen/tree/default/item/COUNTRY-OF-ORIGIN) | 
[Export control classification number(ECCN): EAR99](https://git.sr.ht/~sthagen/sammen/tree/default/item/EXPORT-CONTROL-CLASSIFICATION-NUMBER)

Third party dependencies are documented in the folder [third-party](docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/sammen.svg?style=flat)](https://pypi.python.org/pypi/sammen/)
[![downloads](https://static.pepy.tech/badge/sammen/month)](https://pepy.tech/project/sammen)
[![wheel](https://img.shields.io/pypi/wheel/sammen.svg?style=flat)](https://pypi.python.org/pypi/sammen/)
[![supported-versions](https://img.shields.io/pypi/pyversions/sammen.svg?style=flat)](https://pypi.python.org/pypi/sammen/)
[![supported-implementations](https://img.shields.io/pypi/implementation/sammen.svg?style=flat)](https://pypi.python.org/pypi/sammen/)
[![maintenance-status](https://img.shields.io/github/commit-activity/y/sthagen/sammen.svg?style=flat)](https://git.sr.ht/~sthagen/sammen/log)

## Documentation

User and developer [documentation of sammen](https://codes.dilettant.life/docs/sammen).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of sammen](https://todo.sr.ht/~sthagen/sammen).

## Primary Source repository

The main source of `sammen` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `sammen` are:

* [on codeberg](https://codeberg.org/sthagen/sammen) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/sammen) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

## Status

Experimental.

**Note**: The default branch is `default`.
